@@ -57,14 +57,14 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_s3
-import aws_cdk.core
-import constructs
+import aws_cdk.aws_s3 as _aws_cdk_aws_s3_55f001a5
+import aws_cdk.core as _aws_cdk_core_f4b25747
+import constructs as _constructs_77d1e7e8
 
 
-@jsii.implements(aws_cdk.core.IInspectable)
+@jsii.implements(_aws_cdk_core_f4b25747.IInspectable)
 class CfnGitHubRepository(
-    aws_cdk.core.CfnResource,
+    _aws_cdk_core_f4b25747.CfnResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-codestar.CfnGitHubRepository",
 ):
@@ -106,15 +106,15 @@ class CfnGitHubRepository(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: _aws_cdk_core_f4b25747.Construct,
         id: builtins.str,
         *,
         repository_name: builtins.str,
         repository_owner: builtins.str,
-        code: typing.Optional[typing.Union[typing.Union["CfnGitHubRepository.CodeProperty", typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]] = None,
+        code: typing.Optional[typing.Union[typing.Union["CfnGitHubRepository.CodeProperty", typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]] = None,
         connection_arn: typing.Optional[builtins.str] = None,
-        enable_issues: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
-        is_private: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        enable_issues: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
+        is_private: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
         repository_access_token: typing.Optional[builtins.str] = None,
         repository_description: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -132,21 +132,7 @@ class CfnGitHubRepository(
         :param repository_description: A comment or description about the new repository. This description is displayed in GitHub after the repository is created.
         '''
         if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                repository_name: builtins.str,
-                repository_owner: builtins.str,
-                code: typing.Optional[typing.Union[typing.Union["CfnGitHubRepository.CodeProperty", typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]] = None,
-                connection_arn: typing.Optional[builtins.str] = None,
-                enable_issues: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
-                is_private: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
-                repository_access_token: typing.Optional[builtins.str] = None,
-                repository_description: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__26b449b083110032741dd9724b5a92f29982430d1e05f5d63333a3653c4f8337)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnGitHubRepositoryProps(
@@ -163,15 +149,13 @@ class CfnGitHubRepository(
         jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
-    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+    def inspect(self, inspector: _aws_cdk_core_f4b25747.TreeInspector) -> None:
         '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
         if __debug__:
-            def stub(inspector: aws_cdk.core.TreeInspector) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c13b3396147e53963bba3ead51f99cee7f28e4f126567b00e1dd55d3798216b8)
             check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -184,9 +168,7 @@ class CfnGitHubRepository(
         :param props: -
         '''
         if __debug__:
-            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9f3d420fd6a36b825e10f4fac4dcffb885efe0365d1e5f228e4a1e42a9913b62)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -213,9 +195,7 @@ class CfnGitHubRepository(
     @repository_name.setter
     def repository_name(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ada9a998bd4e3b4cb453bfe71eada51be569d5dc78806fc083aba0cb0b5b64f4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryName", value)
 
@@ -233,9 +213,7 @@ class CfnGitHubRepository(
     @repository_owner.setter
     def repository_owner(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4d47151ed8bc080b487c1a66685dc96d68e8fa4d20cf117b1c89ec62e65174d4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryOwner", value)
 
@@ -243,24 +221,20 @@ class CfnGitHubRepository(
     @jsii.member(jsii_name="code")
     def code(
         self,
-    ) -> typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", _aws_cdk_core_f4b25747.IResolvable]]:
         '''Information about code to be committed to a repository after it is created in an AWS CloudFormation stack.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-code
         '''
-        return typing.cast(typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", aws_cdk.core.IResolvable]], jsii.get(self, "code"))
+        return typing.cast(typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", _aws_cdk_core_f4b25747.IResolvable]], jsii.get(self, "code"))
 
     @code.setter
     def code(
         self,
-        value: typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", aws_cdk.core.IResolvable]],
+        value: typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", _aws_cdk_core_f4b25747.IResolvable]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", aws_cdk.core.IResolvable]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2f57b1016b905ddaabee37dc4a1fd1e22614f03b2460d4c6c51c50c70870f649)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "code", value)
 
@@ -276,9 +250,7 @@ class CfnGitHubRepository(
     @connection_arn.setter
     def connection_arn(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ab0929e046b0f60f895dcb001e270b2545043f0d162061f32081b2e791b9ef7d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "connectionArn", value)
 
@@ -286,26 +258,22 @@ class CfnGitHubRepository(
     @jsii.member(jsii_name="enableIssues")
     def enable_issues(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
         '''Indicates whether to enable issues for the GitHub repository.
 
         You can use GitHub issues to track information and bugs for your repository.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-enableissues
         '''
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]], jsii.get(self, "enableIssues"))
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], jsii.get(self, "enableIssues"))
 
     @enable_issues.setter
     def enable_issues(
         self,
-        value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
+        value: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ce611142bef4a35ed37ee8c0eada80912098229ee1cdfa028edba7cd851b880f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableIssues", value)
 
@@ -313,26 +281,22 @@ class CfnGitHubRepository(
     @jsii.member(jsii_name="isPrivate")
     def is_private(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
         '''Indicates whether the GitHub repository is a private repository.
 
         If so, you choose who can see and commit to this repository.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-isprivate
         '''
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]], jsii.get(self, "isPrivate"))
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], jsii.get(self, "isPrivate"))
 
     @is_private.setter
     def is_private(
         self,
-        value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
+        value: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__08f106dfae269a0beb48d95c12b83a85bf204b5bcffbe10d29496108b5b67f60)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "isPrivate", value)
 
@@ -348,9 +312,7 @@ class CfnGitHubRepository(
     @repository_access_token.setter
     def repository_access_token(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__605cc24b62fe3c1bcd8f7997fbe99a6df9965c4f7638a5dd1d059f62b8c7bc71)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryAccessToken", value)
 
@@ -368,9 +330,7 @@ class CfnGitHubRepository(
     @repository_description.setter
     def repository_description(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0058d63c67af46ad5ec90a867768b28bbe6f57c7675e279f79a16b3e8916894a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryDescription", value)
 
@@ -383,7 +343,7 @@ class CfnGitHubRepository(
         def __init__(
             self,
             *,
-            s3: typing.Union[aws_cdk.core.IResolvable, typing.Union["CfnGitHubRepository.S3Property", typing.Dict[str, typing.Any]]],
+            s3: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union["CfnGitHubRepository.S3Property", typing.Dict[builtins.str, typing.Any]]],
         ) -> None:
             '''The ``Code`` property type specifies information about code to be committed.
 
@@ -411,28 +371,23 @@ class CfnGitHubRepository(
                 )
             '''
             if __debug__:
-                def stub(
-                    *,
-                    s3: typing.Union[aws_cdk.core.IResolvable, typing.Union["CfnGitHubRepository.S3Property", typing.Dict[str, typing.Any]]],
-                ) -> None:
-                    ...
-                type_hints = typing.get_type_hints(stub)
+                type_hints = typing.get_type_hints(_typecheckingstub__754427423db91f6c6b2a4c327c3224c0335085b8310df22e5211ddb92251033a)
                 check_type(argname="argument s3", value=s3, expected_type=type_hints["s3"])
-            self._values: typing.Dict[str, typing.Any] = {
+            self._values: typing.Dict[builtins.str, typing.Any] = {
                 "s3": s3,
             }
 
         @builtins.property
         def s3(
             self,
-        ) -> typing.Union[aws_cdk.core.IResolvable, "CfnGitHubRepository.S3Property"]:
+        ) -> typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnGitHubRepository.S3Property"]:
             '''Information about the Amazon S3 bucket that contains a ZIP file of code to be committed to the repository.
 
             :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codestar-githubrepository-code.html#cfn-codestar-githubrepository-code-s3
             '''
             result = self._values.get("s3")
             assert result is not None, "Required property 's3' is missing"
-            return typing.cast(typing.Union[aws_cdk.core.IResolvable, "CfnGitHubRepository.S3Property"], result)
+            return typing.cast(typing.Union[_aws_cdk_core_f4b25747.IResolvable, "CfnGitHubRepository.S3Property"], result)
 
         def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -488,18 +443,11 @@ class CfnGitHubRepository(
                 )
             '''
             if __debug__:
-                def stub(
-                    *,
-                    bucket: builtins.str,
-                    key: builtins.str,
-                    object_version: typing.Optional[builtins.str] = None,
-                ) -> None:
-                    ...
-                type_hints = typing.get_type_hints(stub)
+                type_hints = typing.get_type_hints(_typecheckingstub__9a905417257973206e54dde52a31e3898c00041afc5a3e67292e8717f2681645)
                 check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
                 check_type(argname="argument key", value=key, expected_type=type_hints["key"])
                 check_type(argname="argument object_version", value=object_version, expected_type=type_hints["object_version"])
-            self._values: typing.Dict[str, typing.Any] = {
+            self._values: typing.Dict[builtins.str, typing.Any] = {
                 "bucket": bucket,
                 "key": key,
             }
@@ -567,10 +515,10 @@ class CfnGitHubRepositoryProps:
         *,
         repository_name: builtins.str,
         repository_owner: builtins.str,
-        code: typing.Optional[typing.Union[typing.Union[CfnGitHubRepository.CodeProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]] = None,
+        code: typing.Optional[typing.Union[typing.Union[CfnGitHubRepository.CodeProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]] = None,
         connection_arn: typing.Optional[builtins.str] = None,
-        enable_issues: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
-        is_private: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
+        enable_issues: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
+        is_private: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
         repository_access_token: typing.Optional[builtins.str] = None,
         repository_description: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -616,19 +564,7 @@ class CfnGitHubRepositoryProps:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                repository_name: builtins.str,
-                repository_owner: builtins.str,
-                code: typing.Optional[typing.Union[typing.Union[CfnGitHubRepository.CodeProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]] = None,
-                connection_arn: typing.Optional[builtins.str] = None,
-                enable_issues: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
-                is_private: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
-                repository_access_token: typing.Optional[builtins.str] = None,
-                repository_description: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8c0c844d2c5533a577aec08aecd7b53c8697af473dfa9d73c9870e56a110eb07)
             check_type(argname="argument repository_name", value=repository_name, expected_type=type_hints["repository_name"])
             check_type(argname="argument repository_owner", value=repository_owner, expected_type=type_hints["repository_owner"])
             check_type(argname="argument code", value=code, expected_type=type_hints["code"])
@@ -637,7 +573,7 @@ class CfnGitHubRepositoryProps:
             check_type(argname="argument is_private", value=is_private, expected_type=type_hints["is_private"])
             check_type(argname="argument repository_access_token", value=repository_access_token, expected_type=type_hints["repository_access_token"])
             check_type(argname="argument repository_description", value=repository_description, expected_type=type_hints["repository_description"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "repository_name": repository_name,
             "repository_owner": repository_owner,
         }
@@ -679,13 +615,13 @@ class CfnGitHubRepositoryProps:
     @builtins.property
     def code(
         self,
-    ) -> typing.Optional[typing.Union[CfnGitHubRepository.CodeProperty, aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[CfnGitHubRepository.CodeProperty, _aws_cdk_core_f4b25747.IResolvable]]:
         '''Information about code to be committed to a repository after it is created in an AWS CloudFormation stack.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-code
         '''
         result = self._values.get("code")
-        return typing.cast(typing.Optional[typing.Union[CfnGitHubRepository.CodeProperty, aws_cdk.core.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[CfnGitHubRepository.CodeProperty, _aws_cdk_core_f4b25747.IResolvable]], result)
 
     @builtins.property
     def connection_arn(self) -> typing.Optional[builtins.str]:
@@ -699,7 +635,7 @@ class CfnGitHubRepositoryProps:
     @builtins.property
     def enable_issues(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
         '''Indicates whether to enable issues for the GitHub repository.
 
         You can use GitHub issues to track information and bugs for your repository.
@@ -707,12 +643,12 @@ class CfnGitHubRepositoryProps:
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-enableissues
         '''
         result = self._values.get("enable_issues")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)
 
     @builtins.property
     def is_private(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]]:
         '''Indicates whether the GitHub repository is a private repository.
 
         If so, you choose who can see and commit to this repository.
@@ -720,7 +656,7 @@ class CfnGitHubRepositoryProps:
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestar-githubrepository.html#cfn-codestar-githubrepository-isprivate
         '''
         result = self._values.get("is_private")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]], result)
 
     @builtins.property
     def repository_access_token(self) -> typing.Optional[builtins.str]:
@@ -773,8 +709,8 @@ class GitHubRepositoryProps:
     def __init__(
         self,
         *,
-        access_token: aws_cdk.core.SecretValue,
-        contents_bucket: aws_cdk.aws_s3.IBucket,
+        access_token: _aws_cdk_core_f4b25747.SecretValue,
+        contents_bucket: _aws_cdk_aws_s3_55f001a5.IBucket,
         contents_key: builtins.str,
         owner: builtins.str,
         repository_name: builtins.str,
@@ -815,20 +751,7 @@ class GitHubRepositoryProps:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                access_token: aws_cdk.core.SecretValue,
-                contents_bucket: aws_cdk.aws_s3.IBucket,
-                contents_key: builtins.str,
-                owner: builtins.str,
-                repository_name: builtins.str,
-                contents_s3_version: typing.Optional[builtins.str] = None,
-                description: typing.Optional[builtins.str] = None,
-                enable_issues: typing.Optional[builtins.bool] = None,
-                visibility: typing.Optional["RepositoryVisibility"] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__03e310e77b0f6f40e3bb812fd1bc49583ce56642771f3c54003c3697f2bc8c31)
             check_type(argname="argument access_token", value=access_token, expected_type=type_hints["access_token"])
             check_type(argname="argument contents_bucket", value=contents_bucket, expected_type=type_hints["contents_bucket"])
             check_type(argname="argument contents_key", value=contents_key, expected_type=type_hints["contents_key"])
@@ -838,7 +761,7 @@ class GitHubRepositoryProps:
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
             check_type(argname="argument enable_issues", value=enable_issues, expected_type=type_hints["enable_issues"])
             check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "access_token": access_token,
             "contents_bucket": contents_bucket,
             "contents_key": contents_key,
@@ -855,24 +778,24 @@ class GitHubRepositoryProps:
             self._values["visibility"] = visibility
 
     @builtins.property
-    def access_token(self) -> aws_cdk.core.SecretValue:
+    def access_token(self) -> _aws_cdk_core_f4b25747.SecretValue:
         '''(experimental) The GitHub user's personal access token for the GitHub repository.
 
         :stability: experimental
         '''
         result = self._values.get("access_token")
         assert result is not None, "Required property 'access_token' is missing"
-        return typing.cast(aws_cdk.core.SecretValue, result)
+        return typing.cast(_aws_cdk_core_f4b25747.SecretValue, result)
 
     @builtins.property
-    def contents_bucket(self) -> aws_cdk.aws_s3.IBucket:
+    def contents_bucket(self) -> _aws_cdk_aws_s3_55f001a5.IBucket:
         '''(experimental) The name of the Amazon S3 bucket that contains the ZIP file with the content to be committed to the new repository.
 
         :stability: experimental
         '''
         result = self._values.get("contents_bucket")
         assert result is not None, "Required property 'contents_bucket' is missing"
-        return typing.cast(aws_cdk.aws_s3.IBucket, result)
+        return typing.cast(_aws_cdk_aws_s3_55f001a5.IBucket, result)
 
     @builtins.property
     def contents_key(self) -> builtins.str:
@@ -973,7 +896,7 @@ class GitHubRepositoryProps:
 
 
 @jsii.interface(jsii_type="@aws-cdk/aws-codestar.IGitHubRepository")
-class IGitHubRepository(aws_cdk.core.IResource, typing_extensions.Protocol):
+class IGitHubRepository(_aws_cdk_core_f4b25747.IResource, typing_extensions.Protocol):
     '''(experimental) GitHubRepository resource interface.
 
     :stability: experimental
@@ -999,7 +922,7 @@ class IGitHubRepository(aws_cdk.core.IResource, typing_extensions.Protocol):
 
 
 class _IGitHubRepositoryProxy(
-    jsii.proxy_for(aws_cdk.core.IResource), # type: ignore[misc]
+    jsii.proxy_for(_aws_cdk_core_f4b25747.IResource), # type: ignore[misc]
 ):
     '''(experimental) GitHubRepository resource interface.
 
@@ -1051,7 +974,7 @@ class RepositoryVisibility(enum.Enum):
 
 @jsii.implements(IGitHubRepository)
 class GitHubRepository(
-    aws_cdk.core.Resource,
+    _aws_cdk_core_f4b25747.Resource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-codestar.GitHubRepository",
 ):
@@ -1079,11 +1002,11 @@ class GitHubRepository(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        access_token: aws_cdk.core.SecretValue,
-        contents_bucket: aws_cdk.aws_s3.IBucket,
+        access_token: _aws_cdk_core_f4b25747.SecretValue,
+        contents_bucket: _aws_cdk_aws_s3_55f001a5.IBucket,
         contents_key: builtins.str,
         owner: builtins.str,
         repository_name: builtins.str,
@@ -1108,22 +1031,7 @@ class GitHubRepository(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                access_token: aws_cdk.core.SecretValue,
-                contents_bucket: aws_cdk.aws_s3.IBucket,
-                contents_key: builtins.str,
-                owner: builtins.str,
-                repository_name: builtins.str,
-                contents_s3_version: typing.Optional[builtins.str] = None,
-                description: typing.Optional[builtins.str] = None,
-                enable_issues: typing.Optional[builtins.bool] = None,
-                visibility: typing.Optional[RepositoryVisibility] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__99e7ea239c3efeec10dca809e128e7979d3913c4069c413a241f37c7523ce9c1)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitHubRepositoryProps(
@@ -1169,3 +1077,141 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__26b449b083110032741dd9724b5a92f29982430d1e05f5d63333a3653c4f8337(
+    scope: _aws_cdk_core_f4b25747.Construct,
+    id: builtins.str,
+    *,
+    repository_name: builtins.str,
+    repository_owner: builtins.str,
+    code: typing.Optional[typing.Union[typing.Union[CfnGitHubRepository.CodeProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]] = None,
+    connection_arn: typing.Optional[builtins.str] = None,
+    enable_issues: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
+    is_private: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
+    repository_access_token: typing.Optional[builtins.str] = None,
+    repository_description: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c13b3396147e53963bba3ead51f99cee7f28e4f126567b00e1dd55d3798216b8(
+    inspector: _aws_cdk_core_f4b25747.TreeInspector,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9f3d420fd6a36b825e10f4fac4dcffb885efe0365d1e5f228e4a1e42a9913b62(
+    props: typing.Mapping[builtins.str, typing.Any],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ada9a998bd4e3b4cb453bfe71eada51be569d5dc78806fc083aba0cb0b5b64f4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4d47151ed8bc080b487c1a66685dc96d68e8fa4d20cf117b1c89ec62e65174d4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2f57b1016b905ddaabee37dc4a1fd1e22614f03b2460d4c6c51c50c70870f649(
+    value: typing.Optional[typing.Union[CfnGitHubRepository.CodeProperty, _aws_cdk_core_f4b25747.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ab0929e046b0f60f895dcb001e270b2545043f0d162061f32081b2e791b9ef7d(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ce611142bef4a35ed37ee8c0eada80912098229ee1cdfa028edba7cd851b880f(
+    value: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__08f106dfae269a0beb48d95c12b83a85bf204b5bcffbe10d29496108b5b67f60(
+    value: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__605cc24b62fe3c1bcd8f7997fbe99a6df9965c4f7638a5dd1d059f62b8c7bc71(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0058d63c67af46ad5ec90a867768b28bbe6f57c7675e279f79a16b3e8916894a(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__754427423db91f6c6b2a4c327c3224c0335085b8310df22e5211ddb92251033a(
+    *,
+    s3: typing.Union[_aws_cdk_core_f4b25747.IResolvable, typing.Union[CfnGitHubRepository.S3Property, typing.Dict[builtins.str, typing.Any]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9a905417257973206e54dde52a31e3898c00041afc5a3e67292e8717f2681645(
+    *,
+    bucket: builtins.str,
+    key: builtins.str,
+    object_version: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8c0c844d2c5533a577aec08aecd7b53c8697af473dfa9d73c9870e56a110eb07(
+    *,
+    repository_name: builtins.str,
+    repository_owner: builtins.str,
+    code: typing.Optional[typing.Union[typing.Union[CfnGitHubRepository.CodeProperty, typing.Dict[builtins.str, typing.Any]], _aws_cdk_core_f4b25747.IResolvable]] = None,
+    connection_arn: typing.Optional[builtins.str] = None,
+    enable_issues: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
+    is_private: typing.Optional[typing.Union[builtins.bool, _aws_cdk_core_f4b25747.IResolvable]] = None,
+    repository_access_token: typing.Optional[builtins.str] = None,
+    repository_description: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__03e310e77b0f6f40e3bb812fd1bc49583ce56642771f3c54003c3697f2bc8c31(
+    *,
+    access_token: _aws_cdk_core_f4b25747.SecretValue,
+    contents_bucket: _aws_cdk_aws_s3_55f001a5.IBucket,
+    contents_key: builtins.str,
+    owner: builtins.str,
+    repository_name: builtins.str,
+    contents_s3_version: typing.Optional[builtins.str] = None,
+    description: typing.Optional[builtins.str] = None,
+    enable_issues: typing.Optional[builtins.bool] = None,
+    visibility: typing.Optional[RepositoryVisibility] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__99e7ea239c3efeec10dca809e128e7979d3913c4069c413a241f37c7523ce9c1(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    access_token: _aws_cdk_core_f4b25747.SecretValue,
+    contents_bucket: _aws_cdk_aws_s3_55f001a5.IBucket,
+    contents_key: builtins.str,
+    owner: builtins.str,
+    repository_name: builtins.str,
+    contents_s3_version: typing.Optional[builtins.str] = None,
+    description: typing.Optional[builtins.str] = None,
+    enable_issues: typing.Optional[builtins.bool] = None,
+    visibility: typing.Optional[RepositoryVisibility] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
